@@ -6,5 +6,6 @@
 # @Email   : 18656170559@163.com
 # @Software: PyCharm
 # @Blog ：http://www.cnblogs.com/yunlongaimeng/
-from cd_mysql import cd_Ms
-from cd_sqlserver import cd_Ss
+from .cd_mysql import cd_Ms
+from .cd_sqlserver import cd_Ss
+
